# biochain

[![codecov](https://codecov.io/gh/bioinfox/biochain/branch/main/graph/badge.svg?token=biochain_token_here)](https://codecov.io/gh/bioinfox/biochain)
[![CI](https://github.com/bioinfox/biochain/actions/workflows/main.yml/badge.svg)](https://github.com/bioinfox/biochain/actions/workflows/main.yml)

Awesome biochain created by bioinfox

## Install it from PyPI

```bash
pip install biochain
```

## Usage

```py
from biochain import BaseClass
from biochain import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m biochain
#or
$ biochain
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
